// import 'package:flutter/gestures.dart';
// import 'package:flutter/widgets.dart';
// import 'package:native_pdf_renderer/native_pdf_renderer.dart';
// import 'package:native_pdf_view/src/native_pdf_view.dart';
// import 'package:zoom_widget/zoom_widget.dart';

part of 'package:native_pdf_view/src/native_pdf_view.dart';

class SimplePdfView extends StatefulWidget {
  const SimplePdfView({
    @required this.controller,
    @required this.onPageChanged,
    @required this.pageLoader,
    @required this.pageBuilder,
    @required this.scrollDirection,
    Key key,
  }) : super(key: key);

  final PdfController controller;

  /// Called whenever the page in the center of the viewport changes
  final void Function(int page) onPageChanged;

  final Widget pageLoader;

  /// Page builder
  final PDFViewPageBuilder pageBuilder;

  /// Page turning direction
  final Axis scrollDirection;

  @override
  _SimplePdfViewState createState() => _SimplePdfViewState();
}

class _SimplePdfViewState extends State<SimplePdfView> {
  ScrollController _scrollController;
  int _currentIndex;
  double _zoomHeight = 10;

  @override
  void initState() {
    _scrollController = ScrollController();
    _currentIndex = widget.controller._pageController.initialPage ?? 0;
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final media = MediaQuery.of(context);
    Size zoomSize;
    final x = media.size.width;
    final y = widget.controller._document.pagesCount * (media.size.height);
    if (widget.scrollDirection == Axis.vertical) {
      zoomSize = Size(x, y);
    } else {
      zoomSize = Size(y, x);
    }

    return Listener(
      onPointerSignal: (PointerSignalEvent event) {
        // if (event is PointerScrollEvent && !widget.pageSnapping) {
        //   widget.controller._pageController.animateTo(
        //     widget.controller._pageController.offset +
        //         (event.scrollDelta.dy * window.devicePixelRatio),
        //     duration: Duration(milliseconds: 75),
        //     curve: Curves.ease,
        //   );
        // }
      },
      child: Zoom(
        width: 1000,
        height: _zoomHeight,
        initZoom: 0,
        child: ListView.builder(
          shrinkWrap: true,
          controller: _scrollController,
          itemBuilder: (BuildContext context, int index) =>
              FutureBuilder<PdfPageImage>(
            future: widget.controller._getPageImage(index),
            builder: (_, snapshot) {
              if (snapshot.hasData) {
                Future.delayed(Duration.zero, () {
                  setState(() {
                    _zoomHeight += snapshot.data.height;
                  });
                });

                return KeyedSubtree(
                  key: Key('$runtimeType.page.'
                      '${widget.controller._document.hashCode}.'
                      '${widget.controller._pages[index].pageNumber}'),
                  child: Container(
                    decoration: BoxDecoration(border: Border.all()),
                    child: widget.pageBuilder(
                      widget.controller._pages[index],
                      index == _currentIndex,
                      null,
                    ),
                  ),
                );
              }

              return KeyedSubtree(
                key: Key('$runtimeType.page.loading'),
                child: widget.pageLoader ?? SizedBox(),
              );
            },
          ),
          itemCount: widget.controller._document.pagesCount,
          physics: NeverScrollableScrollPhysics(),
          scrollDirection: widget.scrollDirection,
        ),
      ),
    );
  }

  /// Default page builder
  static Widget _pageBuilder(
    PdfPageImage pageImage,
    bool isCurrentIndex,
    AnimationController animationController,
  ) {
    Widget image = Image.memory(
      pageImage.bytes,
      key: Key(pageImage.hashCode.toString()),
      fit: BoxFit.contain,
    );

    if (isCurrentIndex) {
      image = Hero(
        tag: 'pdf_view' + pageImage.pageNumber.toString(),
        child: image,
      );
    }
    return image;
  }
}
